
#include <qwidget.h>
#include <qevent.h>
#include <qpainter.h>
#include <qpixmap.h>
#include <passivepopup.h>
#include <qpopupmenu.h>
#include <qfont.h>
#include <qstyle.h>
#include <qpalette.h>

class TTip : public QWidget
{
Q_OBJECT
public:

TTip(QWidget* parent=0, const char* name="");
~TTip();
void updateTip(const QString & e, double speed, const QString& lbl);
private:
void drawIt(QPainter *p);
protected:
void paintEvent(QPaintEvent *e);
virtual void fontChange(const QFont &f);
virtual void styleChange(const QStyle &s);
virtual void paletteChange(const QPalette &p);

QPixmap *buf;
InfoPopup *m_view;

};
